=========
 oslo.db
=========

The Oslo database handling library. Provides database connectivity
to the different backends and helper utils.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   usage
   api/index
   contributing
   history

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
